@@ -20,6 +20,7 @@
 #include "juliaserver.h"
 
 #include <julia/julia.h>
+#include <julia/julia_version.h>
 
 #include <iostream>
 #include <QFileInfo>
@@ -39,8 +40,13 @@ JuliaServer::~JuliaServer()
 
 void JuliaServer::login(const QString &path) const
 {
+#if JULIA_VERSION_MINOR > 5
+    Q_UNUSED(path)
+    jl_init();
+#else
     QString dir_path = QFileInfo(path).dir().absolutePath();
     jl_init(dir_path.toLatin1().constData());
+#endif
 }
 
 void JuliaServer::runJuliaCommand(const QString &command)
@@ -131,4 +137,3 @@ bool JuliaServer::getWasException() const
     return m_was_exception;
 }
 
-#include "juliaserver.moc"
