@@ -33,28 +33,23 @@
 #include <QDir>
 #include <QTemporaryFile>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <QDebug>
 #include <QTimer>
 #include <QRegExp>
 #include <QChar>
 #include <QUrl>
 
-MaximaExpression::MaximaExpression( Cantor::Session* session ) : Cantor::Expression(session)
+MaximaExpression::MaximaExpression( Cantor::Session* session ) : Cantor::Expression(session),
+    m_tempFile(nullptr),
+    m_isHelpRequest(false),
+    m_isPlot(false),
+    m_gotErrorContent(false)
 {
-    qDebug();
-    m_tempFile=0;
 }
 
-MaximaExpression::~MaximaExpression()
-{
-
-}
-
-
 void MaximaExpression::evaluate()
 {
-    qDebug()<<"evaluating "<<command();
     setStatus(Cantor::Expression::Computing);
 
     //until we get the real output Id from maxima, set it to invalid
@@ -65,7 +60,7 @@ void MaximaExpression::evaluate()
     m_gotErrorContent=false;
     if(m_tempFile)
         m_tempFile->deleteLater();
-    m_tempFile=0;
+    m_tempFile=nullptr;
     //check if this is a ?command
     if(command().startsWith(QLatin1Char('?'))||command().startsWith(QLatin1String("describe("))||command().startsWith(QLatin1String("example(")))
         m_isHelpRequest=true;
@@ -140,7 +135,6 @@ void MaximaExpression::evaluate()
 
 void MaximaExpression::interrupt()
 {
-    qDebug()<<"interrupting";
     dynamic_cast<MaximaSession*>(session())->interrupt(this);
     setStatus(Cantor::Expression::Interrupted);
 }
@@ -192,7 +186,7 @@ QString MaximaExpression::internalCommand()
 void MaximaExpression::forceDone()
 {
     qDebug()<<"forcing Expression state to DONE";
-    setResult(0);
+    setResult(nullptr);
     setStatus(Cantor::Expression::Done);
 }
 
@@ -216,7 +210,7 @@ inline void skipWhitespaces(int* idx, const QString& txt)
     for(;*idx < txt.size() && (txt[*idx]).isSpace();++(*idx));
 }
 
-QStringRef readXmlOpeningTag(int* idx, const QString& txt, bool* isComplete=0)
+QStringRef readXmlOpeningTag(int* idx, const QString& txt, bool* isComplete=nullptr)
 {
     qDebug()<<"trying to read an opening tag";
 
@@ -266,7 +260,7 @@ QStringRef readXmlOpeningTag(int* idx, const QString& txt, bool* isComplete=0)
     return QStringRef(&txt, startIndex, length);
 }
 
-QStringRef readXmlTagContent(int* idx, const QString& txt, const QStringRef& name, bool* isComplete=0)
+QStringRef readXmlTagContent(int* idx, const QString& txt, const QStringRef& name, bool* isComplete=nullptr)
 {
     bool readingClosingTag=false;
     int contentStartIdx=*idx;
@@ -328,15 +322,12 @@ bool MaximaExpression::parseOutput(QString& out)
 {
     enum ParserStatus{ReadingOpeningTag, ReadingClosingTag, ReadingText};
     int idx=0;
-
-    qDebug()<<"attempting to parse "<<out;
-
     int numResults=0;
     QString textBuffer;
     QString latexBuffer;
     QString errorBuffer;
 
-    Cantor::Result* result=0;
+    Cantor::Result* result=nullptr;
     while(idx<out.size())
     {
         skipWhitespaces(&idx, out);
@@ -424,7 +415,7 @@ bool MaximaExpression::parseOutput(QString& out)
             }else //got a regular prompt. Just read it all
             {
                 bool isComplete;
-                const QStringRef& content=readXmlTagContent(&idx, out, tag, &isComplete);
+                readXmlTagContent(&idx, out, tag, &isComplete);
 
                 if(!isComplete)
                     return false;
@@ -481,7 +472,7 @@ bool MaximaExpression::parseOutput(QString& out)
                 {
                     //if we got an error message, but also a result, lets just+
                     //assume that it was just a warning, as obviously something worked
-                    if(errorMessage().isEmpty()||result!=0)
+                    if(errorMessage().isEmpty()||result!=nullptr)
                     {
                         setResult(result);
                         setStatus(Cantor::Expression::Done);
@@ -560,7 +551,7 @@ Cantor::Result* MaximaExpression::parseResult(int* idx, QString& out,
         QTimer::singleShot(500, this, SLOT(imageChanged()));
     }
 
-    Cantor::TextResult* result=0;
+    Cantor::TextResult* result=nullptr;
 
     //if this is not the first result, prepend the results
     //found in the earlier tags.
@@ -601,7 +592,7 @@ Cantor::Result* MaximaExpression::parseResult(int* idx, QString& out,
             if(m_isPlot)
                 result=new Cantor::TextResult(i18n("Waiting for Image..."));
             else
-                result=0;
+                result=nullptr;
         }else
         {
             latex.prepend(QLatin1String("\\begin{eqnarray*}\n"));
@@ -641,4 +632,3 @@ QString MaximaExpression::additionalLatexHeaders()
     return QString();
 }
 
-#include "maximaexpression.moc"
