@@ -16,6 +16,7 @@
 
     ---
     Copyright (C) 2009-2012 Alexander Rieder <alexanderrieder@gmail.com>
+    Copyright (C) 2017-2018 Alexander Semke (alexander.semke@web.de)
  */
 
 #include "maximasession.h"
@@ -28,16 +29,14 @@
 #include "settings.h"
 
 #include <QDebug>
+#include <QProcess>
 #include <QTimer>
+
 #include <KMessageBox>
 #include <KLocalizedString>
-#include <signal.h>
 
-#ifdef Q_OS_WIN
-  #include <KProcess>
-#else
-  #include <KPtyProcess>
-  #include <KPtyDevice>
+#ifndef Q_OS_WIN
+#include <signal.h>
 #endif
 
 
@@ -46,75 +45,47 @@
 //the Expressions are encapsulated in () to allow capturing for the text
 const QRegExp MaximaSession::MaximaOutputPrompt=QRegExp(QLatin1String("(\\(\\s*%\\s*O\\s*[0-9\\s]*\\))")); //Text, maxima outputs, before any output
 
-static QString initCmd=QLatin1String(":lisp($load \"%1\")");
 
 MaximaSession::MaximaSession( Cantor::Backend* backend ) : Session(backend),
-    m_initState(MaximaSession::NotInitialized),
-    m_process(0),
-    m_justRestarted(false),
-    m_variableModel(new MaximaVariableModel(this))
-{
-}
-
-MaximaSession::~MaximaSession()
+    m_process(nullptr),
+    m_variableModel(new MaximaVariableModel(this)),
+    m_justRestarted(false)
 {
 }
 
 void MaximaSession::login()
 {
     qDebug()<<"login";
-    emit loginStarted();
 
     if (m_process)
-        m_process->deleteLater();
+        return; //TODO: why do we call login() again?!?
 
-#ifndef Q_OS_WIN
-    m_process=new KPtyProcess(this);
-    m_process->setPtyChannels(KPtyProcess::StdinChannel|KPtyProcess::StdoutChannel);
-    m_process->pty()->setEcho(false);
-    connect(m_process->pty(), SIGNAL(readyRead()), this, SLOT(readStdOut()));
-#else
-    m_process=new KProcess(this);
-    m_process->setOutputChannelMode(KProcess::SeparateChannels);
-    connect(m_process, SIGNAL(readyReadStandardOutput()), this, SLOT(readStdOut()));
-#endif
+    emit loginStarted();
+    QStringList arguments;
+    arguments << QLatin1String("--quiet"); //Suppress Maxima start-up message
+    const QString initFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("cantor/maximabackend/cantor-initmaxima.lisp"));
+    arguments << QLatin1String("--init-lisp=") + initFile; //Set the name of the Lisp initialization file
 
-    m_process->setProgram(MaximaSettings::self()->path().toLocalFile());
-    m_process->start();
+    m_process = new QProcess(this);
+    m_process->start(MaximaSettings::self()->path().toLocalFile(), arguments);
+    m_process->waitForStarted();
+    m_process->waitForReadyRead();
+    qDebug()<<m_process->readAllStandardOutput();
 
     connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(restartMaxima()));
+    connect(m_process, SIGNAL(readyReadStandardOutput()), this, SLOT(readStdOut()));
     connect(m_process, SIGNAL(readyReadStandardError()), this, SLOT(readStdErr()));
     connect(m_process, SIGNAL(error(QProcess::ProcessError)), this, SLOT(reportProcessError(QProcess::ProcessError)));
 
-    const QString initFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("cantor/maximabackend/cantor-initmaxima.lisp"));
-    write(initCmd.arg(initFile));
-
-    Cantor::Expression* expr=evaluateExpression(QLatin1String("print(____END_OF_INIT____);"),
-                                                Cantor::Expression::DeleteOnFinish);
-
-    expr->setInternal(true);
-    //check if we actually landed in the queue and there wasn't some
-    //error beforehand instead
-    if(m_expressionQueue.contains(dynamic_cast<MaximaExpression*>(expr)))
-    {
-        //move this expression to the front
-        m_expressionQueue.prepend(m_expressionQueue.takeLast());
-    }
-
-    //reset the typesetting state
-    setTypesettingEnabled(isTypesettingEnabled());
-
-
-    m_initState=MaximaSession::Initializing;
-
-    if(!MaximaSettings::self()->autorunScripts().isEmpty()){
-        QString autorunScripts = MaximaSettings::self()->autorunScripts().join(QLatin1String("\n"));
-        evaluateExpression(autorunScripts, MaximaExpression::DeleteOnFinish);
-    }
-
-    runFirstExpression();
+    //TODO
+//     if(!MaximaSettings::self()->autorunScripts().isEmpty()){
+//         QString autorunScripts = MaximaSettings::self()->autorunScripts().join(QLatin1String("\n"));
+//         evaluateExpression(autorunScripts, MaximaExpression::DeleteOnFinish);
+// //         runFirstExpression();
+//     }
 
     emit loginDone();
+    qDebug()<<"login done";
 }
 
 void MaximaSession::logout()
@@ -124,42 +95,32 @@ void MaximaSession::logout()
     if(!m_process)
         return;
 
-    disconnect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(restartMaxima()));
+    disconnect(m_process, 0, this, 0);
 
-    if(status()==Cantor::Session::Done)
-    {
-        write(QLatin1String("quit();\n"));
+//     if(status()==Cantor::Session::Running)
+        //TODO: terminate the running expressions first
 
-#ifdef Q_OS_WIN
-        //Give maxima time to clean up
-        qDebug()<<"waiting for maxima to finish";
+    write(QLatin1String("quit();\n"));
+    qDebug()<<"waiting for maxima to finish";
+    m_process->waitForFinished();
+    qDebug()<<"maxima exit finished";
 
-        m_process->waitForFinished();
-#endif
-    }
-    else
-    {
-        m_expressionQueue.clear();
-    }
-
-    //if it is still running, kill just kill it
-    if(m_process->state()!=QProcess::NotRunning)
+    if(m_process->state() != QProcess::NotRunning)
     {
         m_process->kill();
+        qDebug()<<"maxima still running, process kill enforced";
     }
 
-    qDebug()<<"done logging out";
-
-    delete m_process;
-    m_process=0;
-
-    qDebug()<<"destroyed maxima";
-
     m_expressionQueue.clear();
+    delete m_process;
+    m_process = nullptr;
+
+    qDebug()<<"login done";
 }
 
 Cantor::Expression* MaximaSession::evaluateExpression(const QString& cmd, Cantor::Expression::FinishingBehavior behave)
 {
+    qDebug() << "evaluating: " << cmd;
     MaximaExpression* expr = new MaximaExpression(this);
     expr->setFinishingBehavior(behave);
     expr->setCommand(cmd);
@@ -196,44 +157,32 @@ void MaximaSession::readStdErr()
 
 void MaximaSession::readStdOut()
 {
-    qDebug()<<"reading stdOut";
-    if (!m_process)
+    QString out = QLatin1String(m_process->readAllStandardOutput());
+    m_cache += out;
+
+    //collect the multi-line output until Maxima has finished the calculation and returns a new promt
+    if ( !out.contains(QLatin1String("</cantor-prompt>")) )
         return;
-#ifndef Q_OS_WIN
-    QString out=QLatin1String(m_process->pty()->readAll());
-#else
-    QString out=m_process->readAllStandardOutput();
-#endif
-
-    out.remove(QLatin1Char('\r'));
-
-    qDebug()<<"out: "<<out;
-
-    m_cache+=out;
-
-    bool parsingSuccessful=true;
 
     if(m_expressionQueue.isEmpty())
     {
-        qDebug()<<"got output without active expression. dropping: "<<endl
-                <<m_cache;
+        //queue is empty, interrupt was called, nothing to do here
+        qDebug()<<m_cache;
         m_cache.clear();
         return;
     }
 
-    MaximaExpression* expr=m_expressionQueue.first();
+    MaximaExpression* expr = m_expressionQueue.first();
+    if (!expr)
+        return; //should never happen
 
-    if(expr)
-        parsingSuccessful=expr->parseOutput(m_cache);
+    qDebug()<<"start parsing " << "  " << m_cache;
+    if(expr->parseOutput(m_cache))
+        qDebug()<<"parsing successful";
     else
-        parsingSuccessful=false;
-
-    if(parsingSuccessful)
-    {
-        qDebug()<<"parsing successful. dropping "<<m_cache;
-        m_cache.clear();
-    }
+        qDebug() << "failed to parse";
 
+    m_cache.clear();
 }
 
 void MaximaSession::killLabels()
@@ -258,26 +207,6 @@ void MaximaSession::currentExpressionChangedStatus(Cantor::Expression::Status st
     MaximaExpression* expression=m_expressionQueue.first();
     qDebug() << expression << status;
 
-    if(m_initState==MaximaSession::Initializing
-       && expression->command().contains( QLatin1String("____END_OF_INIT____")))
-    {
-        qDebug()<<"initialized";
-        m_expressionQueue.removeFirst();
-
-        m_initState=MaximaSession::Initialized;
-        m_cache.clear();
-
-        runFirstExpression();
-
-        //QTimer::singleShot(0, this, SLOT(killLabels()));
-        killLabels();
-
-        changeStatus(Cantor::Session::Done);
-
-        return;
-    }
-
-
     if(status!=Cantor::Expression::Computing) //The session is ready for the next command
     {
         qDebug()<<"expression finished";
@@ -312,12 +241,6 @@ void MaximaSession::currentExpressionChangedStatus(Cantor::Expression::Status st
 
 void MaximaSession::runFirstExpression()
 {
-    if(m_initState==MaximaSession::NotInitialized)
-    {
-        qDebug()<<"not ready to run expression";
-        return;
-
-    }
     qDebug()<<"running next expression";
     if (!m_process)
         return;
@@ -352,15 +275,16 @@ void MaximaSession::interrupt()
 
 void MaximaSession::interrupt(MaximaExpression* expr)
 {
-    Q_ASSERT(!m_expressionQueue.isEmpty());
-
     if(expr==m_expressionQueue.first())
     {
-        disconnect(expr, 0, this, 0);
-        //TODO for non unix platforms sending signals probably won't work
+        qDebug()<<"interrupting " << expr->command();
+        disconnect(expr, nullptr, this, nullptr);
+#ifndef Q_OS_WIN
         const int pid=m_process->pid();
         kill(pid, SIGINT);
-
+#else
+      //TODO: interrupt the process on windows
+#endif
         qDebug()<<"done interrupting";
     }else
     {
@@ -395,7 +319,7 @@ void MaximaSession::restartMaxima()
     {
         if(!m_expressionQueue.isEmpty())
             m_expressionQueue.removeFirst();
-        KMessageBox::error(0, i18n("Maxima crashed twice within a short time. Stopping to try starting"), i18n("Error - Cantor"));
+        KMessageBox::error(nullptr, i18n("Maxima crashed twice within a short time. Stopping to try starting"), i18n("Error - Cantor"));
     }
 }
 
@@ -438,11 +362,5 @@ QAbstractItemModel* MaximaSession::variableModel()
 
 void MaximaSession::write(const QString& exp) {
     qDebug()<<"sending expression to maxima process: " << exp << endl;
-#ifndef Q_OS_WIN
-    m_process->pty()->write(exp.toUtf8());
-#else
     m_process->write(exp.toUtf8());
-#endif
 }
-
-#include "maximasession.moc"
