@@ -27,8 +27,8 @@ class NullBackend : public Cantor::Backend
 {
   Q_OBJECT
   public:
-    explicit NullBackend( QObject* parent = 0,const QList<QVariant> args = QList<QVariant>());
-    ~NullBackend();
+    explicit NullBackend( QObject* parent = nullptr,const QList<QVariant> args = QList<QVariant>());
+    ~NullBackend() override;
 
     QString id() const Q_DECL_OVERRIDE;
 
