@@ -20,8 +20,11 @@
 #define QALCULATE_SESSION_H
 
 #include "session.h"
+#include "qalculateexpression.h"
 
 #include <QSharedPointer>
+#include <QQueue>
+#include <QMap>
 
 #include <libqalculate/Variable.h>
 #include <libqalculate/MathStructure.h>
@@ -31,14 +34,31 @@ class DefaultVariableModel;
 }
 
 class QalculateEngine;
+class QProcess;
+
 
 class QalculateSession : public Cantor::Session
 {
     Q_OBJECT
 
 private:
-    QList<KnownVariable*> m_ansVariables;
     Cantor::DefaultVariableModel* m_variableModel;
+    QProcess* m_process;
+    QalculateExpression* m_currentExpression;
+    QString m_output;
+    QString m_finalOutput;
+    QString m_currentCommand;
+    QString m_saveError;
+    QQueue<QalculateExpression*> m_expressionQueue;
+    QQueue<QString> m_commandQueue;
+    bool m_isSaveCommand;
+
+
+private:
+    void runExpressionQueue();
+    void runCommandQueue();
+    QString parseSaveCommand(QString& currentCmd);
+    void storeVariables(QString& currentCmd, QString output);
 
 public:
     QalculateSession( Cantor::Backend* backend);
@@ -54,8 +74,17 @@ public:
     virtual Cantor::SyntaxHelpObject* syntaxHelpFor(const QString& cmd);
     virtual QSyntaxHighlighter* syntaxHighlighter(QObject* parent);
 
-    void setLastResult(MathStructure);
+    void runExpression();
     QAbstractItemModel* variableModel();
+
+public:
+    QMap<QString,QString> variables;
+
+public Q_SLOTS:
+    void readOutput();
+    void readError();
+    void processStarted();
+    void currentExpressionStatusChanged(Cantor::Expression::Status status);
 };
 
 #endif
