@@ -28,19 +28,20 @@ class ScilabBackend : public Cantor::Backend
     Q_OBJECT
     
     public:
-        explicit ScilabBackend( QObject* parent = 0,const QList<QVariant> args = QList<QVariant>());
-        ~ScilabBackend();
+        explicit ScilabBackend( QObject* parent = nullptr,const QList<QVariant> args = QList<QVariant>());
+        ~ScilabBackend() override;
 
-        QString id() const;
-        Cantor::Session *createSession();
-        Cantor::Backend::Capabilities capabilities() const;
-        virtual bool requirementsFullfilled() const;
+        QString id() const Q_DECL_OVERRIDE;
+        QString version() const override;
+        Cantor::Session *createSession() Q_DECL_OVERRIDE;
+        Cantor::Backend::Capabilities capabilities() const Q_DECL_OVERRIDE;
+        bool requirementsFullfilled() const Q_DECL_OVERRIDE;
 
-        QWidget* settingsWidget(QWidget* parent) const;
-        KConfigSkeleton* config() const;
+        QWidget* settingsWidget(QWidget* parent) const Q_DECL_OVERRIDE;
+        KConfigSkeleton* config() const Q_DECL_OVERRIDE;
 
-        QUrl helpUrl() const;
-        QString description() const;
+        QUrl helpUrl() const Q_DECL_OVERRIDE;
+        QString description() const Q_DECL_OVERRIDE;
 };
 
 #endif /* _SCILABBACKEND_H */
