@@ -42,6 +42,7 @@
 #include <KMessageBox>
 #include <KNS3/UploadDialog>
 
+#include <QElapsedTimer>
 #include <QFile>
 #include <QTextStream>
 #include <QTextEdit>
@@ -425,15 +426,17 @@ bool CantorPart::openFile()
     }
 
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-    m_worksheet->load(localFilePath());
+    QElapsedTimer timer;
+	timer.start();
+    const bool rc = m_worksheet->load(localFilePath());
     QApplication::restoreOverrideCursor();
 
-    // just for fun, set the status bar
-    //setStatusMessage( m_url.prettyUrl() );
+    if (rc) {
+        qDebug()<< "Worksheet successfully loaded in " <<  (float)timer.elapsed()/1000 << " seconds).";
+        updateCaption();
+    }
 
-    updateCaption();
-
-    return true;
+    return rc;
 }
 
 bool CantorPart::saveFile()
