@@ -21,9 +21,7 @@
 #include "panelplugin.h"
 using namespace Cantor;
 
-#include <KPluginInfo>
-#include <QDebug>
-
+#include <KPluginMetaData>
 class Cantor::PanelPluginPrivate
 {
   public:
@@ -36,8 +34,8 @@ class Cantor::PanelPluginPrivate
 PanelPlugin::PanelPlugin( QObject* parent) : QObject(parent), /* KXMLGUIClient(dynamic_cast<KXMLGUIClient*>(parent)),*/
                                              d(new PanelPluginPrivate)
 {
-    d->parentWidget=0;
-    d->session=0;
+    d->parentWidget=nullptr;
+    d->session=nullptr;
 }
 
 PanelPlugin::~PanelPlugin()
@@ -55,13 +53,12 @@ QWidget* PanelPlugin::parentWidget()
     return d->parentWidget;
 }
 
-void PanelPlugin::setPluginInfo(KPluginInfo info)
+void PanelPlugin::setPluginInfo(KPluginMetaData info)
 {
     d->name=info.name();
-    d->requiredExtensions=info.property(QLatin1String("RequiredExtensions")).toStringList();
+    d->requiredExtensions=info.value(QLatin1String("RequiredExtensions")).split(QLatin1Char(','));
 }
 
-
 QStringList PanelPlugin::requiredExtensions()
 {
     return d->requiredExtensions;
@@ -84,7 +81,6 @@ Session* PanelPlugin::session()
 
 void PanelPlugin::setSession(Session* session)
 {
-    qDebug()<<"setting session to "<<session;
     d->session=session;
     onSessionChanged();
 }
@@ -93,5 +89,3 @@ void PanelPlugin::onSessionChanged()
 {
 
 }
-
-
