@@ -73,7 +73,7 @@ WorksheetTextItem::WorksheetTextItem(QGraphicsObject* parent, Qt::TextInteractio
 WorksheetTextItem::~WorksheetTextItem()
 {
     if (worksheet() && this == worksheet()->lastFocusedTextItem())
-        worksheet()->updateFocusedTextItem(0);
+        worksheet()->updateFocusedTextItem(nullptr);
     if (worksheet() && m_maxWidth > 0 && width() > m_maxWidth)
         worksheet()->removeProtrusion(width() - m_maxWidth);
 }
